==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Navigation/DefaultNavigation/ts/DefaultNavigation_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>DefaultNavigation</name>
    <message>
        <location filename="../DefaultNavigation.js" line="+46"/>
        <source>Graphics View</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Visualizzazione grafica</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Navigation</source>
        <translatorcomment>--google--
Barra di navigazione
Navigazione mappa
Layer ad alta risoluzione possono rallentare la navigazione in QGIS.</translatorcomment>
        <translation>Navigazione</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Zoom (Wheel Mouse)</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Zoom (rotellina del mouse)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Scroll (Trackpad, Multi-Touch Mouse)</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Scorrimento (Trackpad, Multi-Touch Mouse)</translation>
    </message>
</context>
<context>
    <name>GraphicsViewNavigation</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+32"/>
        <source>Mouse wheel / two finger swipe:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Rotella del mouse / due finger swipe:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Enable pan gesture</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Abilita gesto pan</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Reverse mouse wheel direction for zoom</source>
        <translation>Inversa direzione rotellina del mouse per zoom</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Mouse wheel zoom factor:</source>
        <translation>Rotella del mouse fattore di zoom:</translation>
    </message>
    <message>
        <location line="-34"/>
        <source>Limit zoom and scroll to prevent overflows</source>
        <translation>Limitare zoom per evitare overflow</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Navigation/DefaultNavigation/ts/DefaultNavigation_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>DefaultNavigation</name>
    <message>
        <location filename="../DefaultNavigation.js" line="+47"/>
        <source>Graphics View</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Visualizzazione grafica</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Navigation</source>
        <translatorcomment>--google--
Barra di navigazione
Navigazione mappa
Layer ad alta risoluzione possono rallentare la navigazione in QGIS.</translatorcomment>
        <translation>Navigazione</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Zoom (Wheel Mouse)</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Zoom (rotellina del mouse)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Scroll (Trackpad, Multi-Touch Mouse)</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Scorrimento (Trackpad, Multi-Touch Mouse)</translation>
    </message>
</context>
<context>
    <name>GraphicsViewNavigation</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+19"/>
        <source>Mouse wheel / two finger swipe:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Rotella del mouse / due finger swipe:</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Enable pan gesture</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Abilita gesto pan</translation>
    </message>
    <message>
        <location line="-10"/>
        <source>Reverse mouse wheel direction for zoom</source>
        <translation>Inversa direzione rotellina del mouse per zoom</translation>
    </message>
    <message>
        <location line="-7"/>
        <source>Middle mouse button zoom factor:</source>
        <translation>Pulsante centrale del mouse fattore di zoom:</translation>
    </message>
    <message>
        <location line="+34"/>
        <source>Mouse wheel zoom factor:</source>
        <translation>Rotella del mouse fattore di zoom:</translation>
    </message>
    <message>
        <location line="+207"/>
        <source>Panning threshold (px):</source>
        <translation>Soglia della pentola:</translation>
    </message>
    <message>
        <location line="-217"/>
        <source>Limit zoom and scroll to prevent overflows</source>
        <translation>Limitare zoom per evitare overflow</translation>
    </message>
</context>
</TS>
